==> pegasus-merchandise-api-2.2.3-sources.jar: com/thebeastshop/pegasus/merchandise/cond/PcsTagCond.java <==
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.io.Serializable;
import java.util.Date;

public class PcsTagCond extends BaseQueryCond implements Serializable{

	/**
	 * 
	 */
	private static final long serialVersionUID = -3696792461534935879L;
	
	private Long id;

    private String code;

    private String name;

    private String text;

    private Integer active;

    private Date createTime;

    private Date updateTime;

	public PcsTagCond(String code) {
		this.code = code;
	}

	public PcsTagCond() {
		super();
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getText() {
		return text;
	}

	public void setText(String text) {
		this.text = text;
	}

	public Integer getActive() {
		return active;
	}

	public void setActive(Integer active) {
		this.active = active;
	}

	public Date getCreateTime() {
		return createTime;
	}

	public void setCreateTime(Date createTime) {
		this.createTime = createTime;
	}

	public Date getUpdateTime() {
		return updateTime;
	}

	public void setUpdateTime(Date updateTime) {
		this.updateTime = updateTime;
	}
	
	@Override
	public String toString() {
		return "PcsTagCond{" +
				"id='" + id + '\'' +
                ", name='" + name + '\'' +
                ", code='" + code + '\'' +
                ", active='" + active + '\'' +
                ", test=" + text +
                ", createTime='" + createTime + '\'' +
                ", updateTime='" + updateTime + '\'' +
                '}';
	}

}

==> pegasus-merchandise-api-3.9.91-sources.jar: com/thebeastshop/pegasus/merchandise/cond/PcsTagCond.java <==
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.common.BaseQueryCond;

import java.io.Serializable;
import java.util.Date;

public class PcsTagCond extends BaseQueryCond implements Serializable{

	/**
	 * 
	 */
	private static final long serialVersionUID = -3696792461534935879L;
	
	private Long id;

    private String code;

    private String name;

    private String text;

    private Integer active;

    private Date createTime;

    private Date updateTime;

	public PcsTagCond(String code) {
		this.code = code;
	}

	public PcsTagCond() {
		super();
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getText() {
		return text;
	}

	public void setText(String text) {
		this.text = text;
	}

	public Integer getActive() {
		return active;
	}

	public void setActive(Integer active) {
		this.active = active;
	}

	public Date getCreateTime() {
		return createTime;
	}

	public void setCreateTime(Date createTime) {
		this.createTime = createTime;
	}

	public Date getUpdateTime() {
		return updateTime;
	}

	public void setUpdateTime(Date updateTime) {
		this.updateTime = updateTime;
	}
	
	@Override
	public String toString() {
		return "PcsTagCond{" +
				"id='" + id + '\'' +
                ", name='" + name + '\'' +
                ", code='" + code + '\'' +
                ", active='" + active + '\'' +
                ", test=" + text +
                ", createTime='" + createTime + '\'' +
                ", updateTime='" + updateTime + '\'' +
                '}';
	}

}
